raytraverse.renderer
==========================================================

Renderer
---------------------------

.. autoclass:: raytraverse.renderer.Renderer
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

RadianceRenderer
---------------------------

.. autoclass:: raytraverse.renderer.RadianceRenderer
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

Rtrace
--------------------------------

.. autoclass:: raytraverse.renderer.Rtrace
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

Rcontrib
--------------------------------

.. autoclass:: raytraverse.renderer.Rcontrib
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SPRenderer
---------------------------

.. autoclass:: raytraverse.renderer.SPRenderer
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SPRtrace
--------------------------------

.. autoclass:: raytraverse.renderer.SPRtrace
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SPRcontrib
--------------------------------

.. autoclass:: raytraverse.renderer.SPRcontrib
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
